#!/usr/bin/env python
from setuptools import setup, find_packages
import os

cwd = os.path.abspath(os.path.dirname(__file__))

with open(os.path.join(cwd, 'requirements.txt')) as requirements_file:
    requirements = requirements_file.read().splitlines()

setup(
    name='schmecko',
    version='0.0.1',
    author='Ryan Fitzpatrick',
    author_email='rmfitzpatrick@gmail.com',
    url='http://github.com/rmfitzpatrick/schmecko',
    download_url='http://github.com/rmfitzpatrick/schmecko/tarball/master',
    description='Debugging http server',
    license='MIT',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7'
    ],
    packages=find_packages(),
    install_requires=requirements,
    entry_points=dict(
        console_scripts=[
            'schmecko = schmecko.echo_server:run',
        ]
    ),
)



#! /usr/bin/env python
import gzip

from argparse import ArgumentParser
from pprint import pprint
import io

from werkzeug.routing import Rule
from flask import Flask, request, jsonify

app = Flask(__name__)
app.url_map.add(Rule('/<path:path>', endpoint='path'))


@app.endpoint('path')
def echo(path):
    data = request.data
    if request.content_encoding == 'gzip':
        stream = io.BytesIO(data)
        data = gzip.GzipFile(fileobj=stream, mode='rb').read()

    pprint(data)
    response = dict(method=request.method,
                    host=request.host,
                    path=request.path,
                    args=request.args,
                    headers=dict(request.headers.items()),
                    data='')
    return jsonify(response)


ap = ArgumentParser()
ap.add_argument('-p', '--port', default=9080)
ap.add_argument('--host', default='0.0.0.0')


def run():
    args = ap.parse_args()
    app.run(host=args.host, port=args.port, debug=True, use_reloader=True)


if __name__ == '__main__':
    run()
